@@ -38,6 +38,14 @@ class timekprAdminClient(object):
         lastParam = args[len(args)-1]
         timekprForceCLI = False
 
+        # configuration init
+        _timekprConfig = timekprConfig()
+        # load config
+        _timekprConfig.loadMainConfiguration()
+
+        # init logging
+        log.setLogging(_timekprConfig.getTimekprLogLevel(), cons.TK_LOG_TEMP_DIR, (cons.TK_LOG_OWNER_ADMIN_SU if geteuid() == 0 else cons.TK_LOG_OWNER_ADMIN), getpass.getuser())
+
         # check for script
         if ("/timekpra" in lastParam or "timekpra.py" in lastParam):
             # whether we have X running or wayland?
@@ -47,22 +55,14 @@ class timekprAdminClient(object):
 
             # if we are required to run graphical thing
             if (timekprX11Available or timekprWaylandAvailable or timekprMirAvailable):
-                # save logging for later use in classes down tree
-                self._logging = {cons.TK_LOG_L: cons.TK_LOG_LEVEL_DEBUG, cons.TK_LOG_D: cons.TK_LOG_TEMP_DIR, cons.TK_LOG_W: (cons.TK_LOG_OWNER_ADMIN_SU if geteuid() == 0 else cons.TK_LOG_OWNER_ADMIN), cons.TK_LOG_U: getpass.getuser()}
-                # logging init
-                log.setLogging(self._logging)
-
-                # configuration init
-                _timekprConfig = timekprConfig(pLog=self._logging)
-                # load config
-                _timekprConfig.loadMainConfiguration()
                 # resource dir
                 _resourcePathGUI = os.path.join(_timekprConfig.getTimekprSharedDir(), "client/forms")
-
                 # use GUI
                 from timekpr.client.gui.admingui import timekprAdminGUI
                 # load GUI and process from there
                 self._adminGUI = timekprAdminGUI(cons.TK_VERSION, _resourcePathGUI, getpass.getuser())
+                # start GUI
+                self._adminGUI.startAdminGUI()
             # nor X nor wayland are available
             else:
                 # print to console
@@ -82,6 +82,15 @@ class timekprAdminClient(object):
                 # use CLI
                 # validate possible parameters and their values, when fine - execute them as well
                 self.checkAndExecuteAdminCommands(*args)
+                log.flushLogFile()
+
+    # --------------- initialization / helper methods --------------- #
+
+    def finishTimekpr(self, signal=None, frame=None):
+        """Exit timekpr admin GUI gracefully"""
+        if self._adminGUI is not None:
+            # finish main thread on GUI`
+            self._adminGUI.finishTimekpr(signal, frame)
 
     # --------------- parameter validation methods --------------- #
 
@@ -233,6 +242,15 @@ class timekprAdminClient(object):
             else:
                 # set days
                 self.processSetPlayTimeLimitOverride(args[paramIdx+1], args[paramIdx+2])
+        # this sets playtime allowed during unaccounted intervals for user
+        elif adminCmd == "--setplaytimeunaccountedintervalsflag":
+            # check param len
+            if paramLen != paramIdx + 3:
+                # fail
+                adminCmdIncorrect = True
+            else:
+                # set days
+                self.processSetPlayTimeUnaccountedIntervalsEnabled(args[paramIdx+1], args[paramIdx+2])
         # this sets allowed days for PlayTime for the user
         elif adminCmd == "--setplaytimealloweddays":
             # check param len
@@ -344,7 +362,7 @@ class timekprAdminClient(object):
                         # empty
                         hrs = "%s%s" % (uacc, hr) if hrs == "" else "%s;%s%s" % (hrs, uacc, hr)
                 log.consoleOut("%s: %s" % (rUserKey, hrs))
-            elif rUserKey in ("TRACK_INACTIVE", "HIDE_TRAY_INACTIVE", "PLAYTIME_ENABLED", "PLAYTIME_LIMIT_OVERRIDE_ENABLED"):
+            elif rUserKey in ("TRACK_INACTIVE", "HIDE_TRAY_ICON", "PLAYTIME_ENABLED", "PLAYTIME_LIMIT_OVERRIDE_ENABLED", "PLAYTIME_UNACCOUNTED_INTERVALS_ENABLED"):
                 log.consoleOut("%s: %s" % (rUserKey, bool(rUserConfig)))
             elif rUserKey in ("PLAYTIME_ACTIVITIES"):
                 # result
@@ -425,8 +443,10 @@ class timekprAdminClient(object):
 
         # day limists
         try:
-            # try to parse parameters
-            dayLimits = list(map(int, pDayLimits.split(";")))
+            # allow empty limits too
+            if str(pDayLimits) != "":
+                # try to parse parameters
+                dayLimits = list(map(int, pDayLimits.split(";")))
         except Exception as ex:
             # fail
             result = -1
@@ -641,6 +661,30 @@ class timekprAdminClient(object):
             # log error
             log.consoleOut(message)
 
+    def processSetPlayTimeUnaccountedIntervalsEnabled(self, pUserName, pPlayTimeUnaccountedIntervalsEnabled):
+        """Process PlayTime allowed during unaccounted intervals flag"""
+        # defaults
+        isPlayTimeUnaccountedIntervalsEnabled = None
+        result = 0
+
+        # check
+        if pPlayTimeUnaccountedIntervalsEnabled not in ("true", "True", "TRUE", "false", "False", "FALSE"):
+            # fail
+            result = -1
+            message = msg.getTranslation("TK_MSG_PARSE_ERROR") % ("please specify true or false")
+        else:
+            isPlayTimeUnaccountedIntervalsEnabled = True if pPlayTimeUnaccountedIntervalsEnabled in ("true", "True", "TRUE") else False
+
+        # preprocess successful
+        if result == 0:
+            # invoke
+            result, message = self._timekprAdminConnector.setPlayTimeUnaccountedIntervalsEnabled(pUserName, isPlayTimeUnaccountedIntervalsEnabled)
+
+        # process
+        if result != 0:
+            # log error
+            log.consoleOut(message)
+
     def processSetPlayTimeAllowedDays(self, pUserName, pPlayTimeDayList):
         """Process allowed days for PlayTime"""
         # defaults
@@ -659,7 +703,7 @@ class timekprAdminClient(object):
         # preprocess successful
         if result == 0:
             # invoke
-            result, message = self._timekprAdminConnector.setPlayTimeAllowedDaysForDays(pUserName, dayMap)
+            result, message = self._timekprAdminConnector.setPlayTimeAllowedDays(pUserName, dayMap)
 
         # process
         if result != 0:
@@ -674,8 +718,10 @@ class timekprAdminClient(object):
 
         # day limists
         try:
-            # try to parse parameters
-            dayLimits = list(map(int, pPlayTimeDayLimits.split(";")))
+            # allow empty limits too
+            if pPlayTimeDayLimits != "":
+                # try to parse parameters
+                dayLimits = list(map(int, pPlayTimeDayLimits.split(";")))
         except Exception as ex:
             # fail
             result = -1
