@@ -24,11 +24,8 @@ DBusGMainLoop(set_as_default=True)
 class timekprNotifications(object):
     """Main class for supporting indicator notifications, connect to request methods for timekpr and connections to other DBUS modules"""
 
-    def __init__(self, pLog, pUserName, pTimekprClientConfig):
+    def __init__(self, pUserName, pTimekprClientConfig):
         """Initialize notifications"""
-        # init logging firstly
-        log.setLogging(pLog)
-
         log.log(cons.TK_LOG_LEVEL_INFO, "start init timekpr notifications")
 
         # uname
@@ -182,10 +179,10 @@ class timekprNotifications(object):
                 log.log(cons.TK_LOG_LEVEL_DEBUG, "CONNECTED to DBUS %s (%s) interface" % (self.CL_CONN_SCR, iNames[chosenIdx]))
                 # add a connection to signal
                 self._dbusConnections[self.CL_CONN_SCR][self.CL_SI] = self._userSessionBus.add_signal_receiver(
-                     path             = iPaths[chosenIdx]
-                    ,handler_function = self.receiveScreenSaverActivityChange
-                    ,dbus_interface   = iNames[chosenIdx]
-                    ,signal_name      = "ActiveChanged")
+                    path             = iPaths[chosenIdx],
+                    handler_function = self.receiveScreenSaverActivityChange,
+                    dbus_interface   = iNames[chosenIdx],
+                    signal_name      = "ActiveChanged")
 
         # only if screensaver is not ok
         if self._dbusConnections[self.CL_CONN_TK][self.CL_IF] is None and self._dbusConnections[self.CL_CONN_TK][self.CL_CNT] > 0 and not self._dbusConnections[self.CL_CONN_TK][self.CL_DEL] > 0:
@@ -359,7 +356,7 @@ class timekprNotifications(object):
             # notify through dbus
             try:
                 # call dbus method
-                notifId = self._dbusConnections[self.CL_CONN_NOTIF][self.CL_IF].Notify("Timekpr", notifId, timekprIcon, msg.getTranslation("TK_MSG_NOTIFICATION_PLAYTIME_TITLE" if pMsgType == "PlayTime" else "TK_MSG_NOTIFICATION_TITLE"), msgStr, actions, hints, notificationTimeout)
+                notifId = self._dbusConnections[self.CL_CONN_NOTIF][self.CL_IF].Notify("Timekpr", notifId if pMsgType != "PlayTime" else 0, timekprIcon, msg.getTranslation("TK_MSG_NOTIFICATION_PLAYTIME_TITLE" if pMsgType == "PlayTime" else "TK_MSG_NOTIFICATION_TITLE"), msgStr, actions, hints, notificationTimeout)
             except Exception as dbusEx:
                 # we cannot send notif through dbus
                 self._dbusConnections[self.CL_CONN_NOTIF][self.CL_IF] = None
@@ -368,8 +365,9 @@ class timekprNotifications(object):
                 log.log(cons.TK_LOG_LEVEL_INFO, str(dbusEx))
                 log.log(cons.TK_LOG_LEVEL_INFO, "--=== ERROR sending message through dbus ===---")
 
-            # save notification ID (to replace it)
-            self._lastNotifId = notifId
+            # save notification ID (only if message is not about PlayTime, otherwise it may dismiss standard time or vice versa)
+            if pMsgType != "PlayTime":
+                self._lastNotifId = notifId
 
             # user wants to hear things
             if self._timekprClientConfig.getIsNotificationSpeechSupported() and self._timekprClientConfig.getClientUseSpeechNotifications():
@@ -477,10 +475,10 @@ class timekprNotifications(object):
             try:
                 # call dbus method
                 result, message = self._dbusConnections[self.CL_CONN_TK][self.CL_IFA].processUserSessionAttributes(
-                    self._userName
-                    ,dbus.String(pWhat if pWhat is not None else "")
-                    ,dbus.String(pKey if pKey is not None else "")
-                    ,dbus.String(pValue if pValue is not None else ""))
+                    self._userName,
+                    dbus.String(pWhat if pWhat is not None else ""),
+                    dbus.String(pKey if pKey is not None else ""),
+                    dbus.String(pValue if pValue is not None else ""))
 
                 # check call result
                 if result != 0:
