@@ -18,10 +18,8 @@ class timekprNotificationManager(dbus.service.Object):
 
     # --------------- initialization / control methods --------------- #
 
-    def __init__(self, pLog, pBusName, pUserName, pTimekprConfig):
+    def __init__(self, pBusName, pUserName, pTimekprConfig):
         """Initialize notification manager"""
-        # init logging firstly
-        log.setLogging(pLog)
 
         log.log(cons.TK_LOG_LEVEL_INFO, "start init notifications")
 
@@ -80,7 +78,7 @@ class timekprNotificationManager(dbus.service.Object):
 
     def processTimeLeft(self, pForce, pTimeValues):
         """Process notifications and send signals if needed"""
-        log.log(cons.TK_LOG_LEVEL_DEBUG, "start processTimeLeft")
+        log.log(cons.TK_LOG_LEVEL_EXTRA_DEBUG, "start processTimeLeft")
 
         # save old level
         self._prevNotificationLvl = self._notificationLvl
@@ -114,15 +112,19 @@ class timekprNotificationManager(dbus.service.Object):
         # include PlayTime (if enabled, check is done for couple of mandatory values)
         if cons.TK_CTRL_PTTLO in pTimeValues and cons.TK_CTRL_PTSPD in pTimeValues:
             timeLeft[cons.TK_CTRL_PTTLO] = (1 if pTimeValues[cons.TK_CTRL_PTTLO] else 0)
+            timeLeft[cons.TK_CTRL_PTAUH] = (1 if pTimeValues[cons.TK_CTRL_PTAUH] else 0)
             timeLeft[cons.TK_CTRL_PTSPD] = int(pTimeValues[cons.TK_CTRL_PTSPD])
             timeLeft[cons.TK_CTRL_PTLPD] = int(pTimeValues[cons.TK_CTRL_PTLPD])
             timeLeft[cons.TK_CTRL_PTLSTC] = int(pTimeValues[cons.TK_CTRL_PTLSTC])
 
+        # save calculated urgency (calculated may get overridden by uacc)
+        notifUrgency = cons.TK_PRIO_UACC if pTimeValues[cons.TK_CTRL_UACC] else self._notificationLimits[self._notificationLvl][cons.TK_NOTIF_URGENCY]
+
         # inform clients about time left in any case
-        self.timeLeft(self._notificationLimits[self._notificationLvl][cons.TK_NOTIF_URGENCY], timeLeft)
+        self.timeLeft(notifUrgency, timeLeft)
 
         # if notification levels changed (and it was not the first iteration)
-        if (pForce) or (self._notificationLvl != self._prevNotificationLvl) or ((effectiveDatetime - self._lastNotified).total_seconds() >= self._notificationLimits[self._notificationLvl][cons.TK_NOTIF_INTERVAL]()):
+        if (pForce) or (self._notificationLvl != self._prevNotificationLvl) or ((effectiveDatetime - self._lastNotified).total_seconds() >= self._notificationLimits[self._notificationLvl][cons.TK_NOTIF_INTERVAL]() and not pTimeValues[cons.TK_CTRL_UACC]):
             # set up last notified
             self._lastNotified = effectiveDatetime
 
@@ -134,10 +136,10 @@ class timekprNotificationManager(dbus.service.Object):
                     self.timeNoLimitNotification(cons.TK_PRIO_LOW)
             else:
                 # limit
-                self.timeLeftNotification(self._notificationLimits[self._notificationLvl][cons.TK_NOTIF_URGENCY], max(pTimeValues[cons.TK_CTRL_LEFT], 0), max(pTimeValues[cons.TK_CTRL_LEFTD], 0), pTimeValues[cons.TK_CTRL_LIMITD])
+                self.timeLeftNotification(notifUrgency, max(pTimeValues[cons.TK_CTRL_LEFT], 0), max(pTimeValues[cons.TK_CTRL_LEFTD], 0), pTimeValues[cons.TK_CTRL_LIMITD])
 
-        log.log(cons.TK_LOG_LEVEL_DEBUG, "time left: %i; %i; %i, notification lvl: %s, priority: %s, force: %s" % (pTimeValues[cons.TK_CTRL_LEFT], pTimeValues[cons.TK_CTRL_LEFTD], pTimeValues[cons.TK_CTRL_LIMITD], self._notificationLvl, self._notificationLimits[self._notificationLvl][cons.TK_NOTIF_URGENCY], str(pForce)))
-        log.log(cons.TK_LOG_LEVEL_DEBUG, "finish processTimeLeft")
+        log.log(cons.TK_LOG_LEVEL_DEBUG, "time left, tlrow: %i, tleftd: %i, tlimd: %i, notification lvl: %s, priority: %s, force: %s" % (pTimeValues[cons.TK_CTRL_LEFT], pTimeValues[cons.TK_CTRL_LEFTD], pTimeValues[cons.TK_CTRL_LIMITD], self._notificationLvl, notifUrgency, str(pForce)))
+        log.log(cons.TK_LOG_LEVEL_EXTRA_DEBUG, "finish processTimeLeft")
 
     def processTimeLimits(self, pTimeLimits):
         """Enable sending out the limits config"""
@@ -147,11 +149,16 @@ class timekprNotificationManager(dbus.service.Object):
         # convert this all to dbus
         for rKey, rValue in pTimeLimits.items():
             # weekly & monthly limits are set differently
-            if rKey in (cons.TK_CTRL_LIMITW, cons.TK_CTRL_LIMITM, cons.TK_CTRL_PTTLO, cons.TK_CTRL_PTTLE):
+            if rKey in (cons.TK_CTRL_LIMITW, cons.TK_CTRL_LIMITM):
                 # this is to comply with standard limits structure
                 timeLimits[rKey] = dbus.Dictionary(signature="sv")
                 timeLimits[rKey][rKey] = dbus.Int32(rValue)
-            # PlayTime
+            # PlayTime flags
+            elif rKey in (cons.TK_CTRL_PTTLO, cons.TK_CTRL_PTAUH, cons.TK_CTRL_PTTLE):
+                # this is to comply with standard limits structure
+                timeLimits[rKey] = dbus.Dictionary(signature="sv")
+                timeLimits[rKey][rKey] = dbus.Int32(rValue)
+            # PlayTime lists
             elif rKey in (cons.TK_CTRL_PTLMT, cons.TK_CTRL_PTLST):
                 # dbus dict for holding days, limits and activities
                 timeLimits[rKey] = dbus.Dictionary(signature="sv")
@@ -170,7 +177,7 @@ class timekprNotificationManager(dbus.service.Object):
                     # add intervals
                     timeLimits[rKey][cons.TK_CTRL_INT].append(dbus.Array([rLimit[0], rLimit[1], rLimit[2]], signature="i"))
 
-        if log.isDebug():
+        if log.isDebugEnabled(cons.TK_LOG_LEVEL_EXTRA_DEBUG):
             log.log(cons.TK_LOG_LEVEL_EXTRA_DEBUG, "TLDB: %s" % (str(timeLimits)))
 
         # process
