@@ -16,10 +16,8 @@ from timekpr.common.utils import misc
 class timekprUserManager(object):
     """A connection with login1 and other DBUS servers."""
 
-    def __init__(self, pLog, pUserName, pUserPathOnBus):
+    def __init__(self, pUserName, pUserPathOnBus):
         """Initialize manager."""
-        # init logging firstly
-        log.setLogging(pLog)
 
         # save the bus and user
         self._timekprBus = dbus.SystemBus()
@@ -49,7 +47,7 @@ class timekprUserManager(object):
 
     def cacheUserSessionList(self):
         """Determine user sessions and cache session objects for further reference."""
-        log.log(cons.TK_LOG_LEVEL_DEBUG, "---=== start cacheUserSessionList for \"%s\" ===---" % (self._userName))
+        log.log(cons.TK_LOG_LEVEL_EXTRA_DEBUG, "---=== start cacheUserSessionList for \"%s\" ===---" % (self._userName))
         # dbus performance measurement
         misc.measureTimeElapsed(pStart=True)
         # get all user sessions
@@ -95,7 +93,6 @@ class timekprUserManager(object):
                 self._timekprUserSessions[sessionId] = {cons.TK_CTRL_DBUS_SESS_OBJ: sessionObject, cons.TK_CTRL_DBUS_SESS_IF: sessionInterface, cons.TK_CTRL_DBUS_SESS_PROP_IF: sessionPropertiesInterface, cons.TK_CTRL_DBUS_SESS_PROP: {}}
 
                 # add static properties
-                self._timekprUserSessions[sessionId][cons.TK_CTRL_DBUS_SESS_PROP]["Type"] = str(sessionPropertiesInterface.Get(cons.TK_DBUS_SESSION_OBJECT, "Type"))
                 self._timekprUserSessions[sessionId][cons.TK_CTRL_DBUS_SESS_PROP]["VTNr"] = str(int(sessionPropertiesInterface.Get(cons.TK_DBUS_SESSION_OBJECT, "VTNr")))
                 self._timekprUserSessions[sessionId][cons.TK_CTRL_DBUS_SESS_PROP]["Seat"] = str(sessionPropertiesInterface.Get(cons.TK_DBUS_SESSION_OBJECT, "Seat")[0])
             else:
@@ -109,7 +106,7 @@ class timekprUserManager(object):
             log.log(cons.TK_LOG_LEVEL_DEBUG, "removing session: %s" % (userSession))
             self._timekprUserSessions.pop(userSession)
 
-        log.log(cons.TK_LOG_LEVEL_DEBUG, "---=== finish cacheUserSessionList for \"%s\" ===---" % (self._userName))
+        log.log(cons.TK_LOG_LEVEL_EXTRA_DEBUG, "---=== finish cacheUserSessionList for \"%s\" ===---" % (self._userName))
 
     def isUserActive(self, pTimekprConfig, pTimekprUserConfig, pIsScreenLocked):
         """Check if user is active."""
@@ -132,8 +129,7 @@ class timekprUserManager(object):
         #    screenlocker status from user DBUS session
 
         # init active sessions
-        userActive = False
-        userScreenLocked = False
+        userActive = userScreenLocked = False
         sessionLockedState = "False"
 
         # if user locked the computer
@@ -148,9 +144,9 @@ class timekprUserManager(object):
                 sessionLockedState = "False"
 
                 # get needed static properties
-                sessionType = self._timekprUserSessions[rSessionId][cons.TK_CTRL_DBUS_SESS_PROP]["Type"]
                 sessionVTNr = self._timekprUserSessions[rSessionId][cons.TK_CTRL_DBUS_SESS_PROP]["VTNr"]
                 # get needed properties
+                sessionType = str(self._timekprUserSessions[rSessionId][cons.TK_CTRL_DBUS_SESS_PROP_IF].Get(cons.TK_DBUS_SESSION_OBJECT, "Type"))
                 sessionState = str(self._timekprUserSessions[rSessionId][cons.TK_CTRL_DBUS_SESS_PROP_IF].Get(cons.TK_DBUS_SESSION_OBJECT, "State"))
                 sessionIdleState = str(bool(self._timekprUserSessions[rSessionId][cons.TK_CTRL_DBUS_SESS_PROP_IF].Get(cons.TK_DBUS_SESSION_OBJECT, "IdleHint")))
                 # get locked state, only if it's available
@@ -174,10 +170,14 @@ class timekprUserManager(object):
 
                 # check if active
                 if sessionState == "active" and sessionIdleState == "False" and sessionLockedState == "False":
+                    # validate against session types we specifically do not track
+                    if sessionType in pTimekprConfig.getTimekprSessionsExcl():
+                        # session is on the list of session types we specifically do not track
+                        log.log(cons.TK_LOG_LEVEL_DEBUG, "session %s is active, but session type \"%s\" is excluded from tracking (thus effectively inactive)" % (rSessionId, sessionType))
                     # validate against session types we manage
-                    if sessionType not in pTimekprConfig.getTimekprSessionsCtrl():
+                    elif sessionType not in pTimekprConfig.getTimekprSessionsCtrl():
                         # session is not on the list of session types we track
-                        log.log(cons.TK_LOG_LEVEL_DEBUG, "session %s is active, but excluded (thus effectively inactive)" % (rSessionId))
+                        log.log(cons.TK_LOG_LEVEL_DEBUG, "session %s is active, but session type \"%s\" is not on tracked type list (thus effectively inactive)" % (rSessionId, sessionType))
                     else:
                         # session is on the list of session types we track and session is active
                         userActive = True
@@ -200,7 +200,7 @@ class timekprUserManager(object):
                         log.log(cons.TK_LOG_LEVEL_DEBUG, "session %s inactive" % (rSessionId))
                 else:
                     # session is not on the list of session types we track
-                    log.log(cons.TK_LOG_LEVEL_DEBUG, "session %s not tracked" % (rSessionId))
+                    log.log(cons.TK_LOG_LEVEL_DEBUG, "session %s is inactive and not tracked" % (rSessionId))
 
         # screen lock state
         userScreenLocked = (pIsScreenLocked or sessionLockedState == "True")
@@ -213,8 +213,8 @@ class timekprUserManager(object):
     def lockUserSessions(self):
         """Ask login manager to lock user sessions"""
         # go through all user sessions
-        for sessionId in self._timekprUserSessions:
+        for rSessionId in self._timekprUserSessions:
             # we lock only GUI sessions
-            if self._timekprUserSessions[sessionId][cons.TK_CTRL_DBUS_SESS_PROP]["Type"] in cons.TK_SESSION_TYPES_CTRL:
+            if str(self._timekprUserSessions[rSessionId][cons.TK_CTRL_DBUS_SESS_PROP_IF].Get(cons.TK_DBUS_SESSION_OBJECT, "Type")) in cons.TK_SESSION_TYPES_CTRL:
                 # lock session
-                self._timekprUserSessions[sessionId][cons.TK_CTRL_DBUS_SESS_IF].Lock()
+                self._timekprUserSessions[rSessionId][cons.TK_CTRL_DBUS_SESS_IF].Lock()
