@@ -30,6 +30,9 @@ if __name__ == "__main__":
         sys.exit(0)
 
     log.log(cons.TK_LOG_LEVEL_INFO, "--- initiating timekpr v. %s ---" % (cons.TK_VERSION))
+    # get uname
+    uname = os.uname()
+    log.log(cons.TK_LOG_LEVEL_INFO, "running on: %s, %s, %s, %s" % (uname[0], uname[2], uname[3], uname[4]))
 
     # get daemon class
     _timekprDaemon = timekprDaemon()
